@@ -209,7 +209,8 @@ object can be used for multiple fetches, so this normally only needs to be
 called once.
 
 I<options> is a hash of option/value pairs (ie. "-option" => "value").  
-The currently-supported options are:  
+If an "-option" is specified with no "value" given, the default value will 
+be I<1> ("I<true>").  The currently-supported options are:  
 
 =over 4
 
@@ -256,24 +257,6 @@ one level of debug verbosity.
 
 =back 
 
-=item [ I<$current-agent string> = ] $finder->B<agent>( [ I<user-agent string> ] )
-
-This method, included here for compatibility only, is only useful for the 
-other site modules that access the internet, but is ignored here.
-
-Set the desired user-agent (ie. browser name) to pass to www.azlyrics.com.  
-Some sites are pickey about receiving a user-agent 
-string that corresponds to a valid / supported web-browser to prevent their 
-sites from being "scraped" by programs, such as this.  
-
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">
-
-If no argument is passed, it returns the current GENERAL user-agent string in 
-effect (but a different agent option is specified for a specific module may 
-have been specified and used by THAT module - see B<new>() options above).
-
-NOTE:  This will override any B<-agent> option value specified in B<new>()!
-
 =item [ I<$current-directory> = ] $finder->B<cache>( [ I<$directory> ] )
 
 Specifies a directory (ie. "/home/user/Music/Lyricsfiles") to be used for 
